@@ -117,7 +117,7 @@ def make_inet_project_description(inet_version, omnetpp_versions):
         "smoke_test_commands": [
             "cd examples/ethernet/arptest",
             # get whether the inet lib is upper or lower-case
-            """INET_LIB_CASE='INET'""" if inet_version > "2.6.0" else """INET_LIB_CASE='inet'""",
+            """INET_LIB_CASE='INET'""" if inet_version > "2.6.x" else """INET_LIB_CASE='inet'""",
             """if [ "$mode" = "debug" ]; then OPP_BIN=$OPP_RUN_DBG_BIN; INET_DBG_SUFFIX="_dbg"; INET_LIB=$(echo $INET_ROOT/out/*-debug/src/*$INET_LIB_CASE*); fi""",
             """if [ "$mode" = "release" ]; then OPP_BIN=$OPP_RUN_RELEASE_BIN; INET_DBG_SUFFIX=""; INET_LIB=$(echo $INET_ROOT/out/*-release/src/*$INET_LIB_CASE*); fi""",
             "$OPP_BIN -l $INET_LIB -n $INET_ROOT/examples:.:$INET_ROOT/src -c ARPTest -u Cmdenv --sim-time-limit=10s" if inet_version < "4.0" else
@@ -167,7 +167,7 @@ def make_inet_project_description(inet_version, omnetpp_versions):
                 "setenv_commands": [
                     "@append",
                     "export MININET_ROOT=${pkgs.python311Packages.mininet-python}",
-                    "echo '\nNote on the Emulation feature: after installation, make sure to add the necessary capabilities to omnetpp executables by running the following commands:\n\nsudo setcap cap_sys_admin+ep /$OMNETPP_ROOT/bin/opp_run_release\nsudo setcap cap_sys_admin+ep /$OMNETPP_ROOT/bin/opp_run_dbg\n'",
+                    "echo '\nNote on the Emulation feature: after installation, make sure to add the necessary capabilities to omnetpp executables by running the following commands:\n\nsudo setcap cap_sys_admin+ep $OMNETPP_ROOT/bin/opp_run_release\nsudo setcap cap_sys_admin+ep $OMNETPP_ROOT/bin/opp_run_dbg\n'",
                     "if [ \"$(uname -s)\" != 'Linux' ]; then echo 'WARNING: Network-emulation-related functionality only works on Linux.'; fi",
                 ],
                 "patch_commands": [
